@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-cite-overlay-sidecar" "1.1.1"
+(define-package "org-cite-overlay-sidecar" "20251130.300"
   "Show Sidecar for overlaid org-cite citations."
   '((emacs                      "28.1")
     (citeproc                   "0.9.4")
